package com.linghu.util;


import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import java.io.StringReader;
import java.io.StringWriter;


/**
 * 封装了XML转换成object，object转换成XML的代码
 *
 * @author xcq
 * {@code @date} 2023/03/09
 */
public class XmlUtil {


    /**
     * xml字符串转换为对象
     *
     * @param tClazz t clazz
     * @param string 字符串
     * @return {@link T}
     * @throws JAXBException jaxbexception
     */
    public static <T>T convertToObject(String string, Class<T> tClazz) throws JAXBException {
        JAXBContext context = JAXBContext.newInstance(tClazz);
        Unmarshaller unmarshaller = context.createUnmarshaller();
        try (StringReader sr = new StringReader(string)) {
            return (T) unmarshaller.unmarshal(sr);
        }
    }

    /**
     * 将对象转为xml字符串 编码为utf-8
     *
     * @param obj       待转的对象
     * @return String   xml字符串
     */
    public static String objectToXml(Object obj) throws JAXBException {
        JAXBContext context = JAXBContext.newInstance(obj.getClass());
        Marshaller marshaller = context.createMarshaller();
        marshaller.setProperty(Marshaller.JAXB_ENCODING, "UTF-8");
        marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, true);
        marshaller.setProperty(Marshaller.JAXB_FRAGMENT, true);
//        marshaller.setProperty(CharacterEscapeHandler.class.getName(), (CharacterEscapeHandler) (ch, start, length, isAttVal, writer) -> writer.write(ch, start, length));
        StringWriter writer = new StringWriter();
        marshaller.marshal(obj, writer);
        return writer.toString();
    }

}

